@@ -67,6 +67,64 @@ class BindOrganizationMemberAuthAccountResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class CreateOrganizationMemberPolicyRequest(AbstractModel):
+    """CreateOrganizationMemberPolicy请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param MemberUin: 成员Uin。
+        :type MemberUin: int
+        :param PolicyName: 策略名。
+        :type PolicyName: str
+        :param IdentityId: 身份ID。
+        :type IdentityId: int
+        :param Description: 描述。
+        :type Description: str
+        """
+        self.MemberUin = None
+        self.PolicyName = None
+        self.IdentityId = None
+        self.Description = None
+
+
+    def _deserialize(self, params):
+        self.MemberUin = params.get("MemberUin")
+        self.PolicyName = params.get("PolicyName")
+        self.IdentityId = params.get("IdentityId")
+        self.Description = params.get("Description")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class CreateOrganizationMemberPolicyResponse(AbstractModel):
+    """CreateOrganizationMemberPolicy返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param PolicyId: 策略ID。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type PolicyId: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.PolicyId = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.PolicyId = params.get("PolicyId")
+        self.RequestId = params.get("RequestId")
+
+
 class CreateOrganizationMemberRequest(AbstractModel):
     """CreateOrganizationMember请求参数结构体
 
@@ -76,11 +134,11 @@ class CreateOrganizationMemberRequest(AbstractModel):
         r"""
         :param Name: 名称
         :type Name: str
-        :param PolicyType: 关系策略
+        :param PolicyType: 关系策略  取值：Financial
         :type PolicyType: str
-        :param PermissionIds: 关系权限
+        :param PermissionIds: 关系权限 取值：1-查看账单、2-查看余额、3-资金划拨、4-合并出账、5-开票 ，1、2 默认必须
         :type PermissionIds: list of int non-negative
-        :param NodeId: 需要调节的节点
+        :param NodeId: 成员所属部门的节点ID
         :type NodeId: int
         :param AccountName: 账号名
         :type AccountName: str
@@ -88,6 +146,12 @@ class CreateOrganizationMemberRequest(AbstractModel):
         :type Remark: str
         :param RecordId: 重试创建传记录ID
         :type RecordId: int
+        :param PayUin: 代付者Uin
+        :type PayUin: str
+        :param IdentityRoleID: 管理身份
+        :type IdentityRoleID: list of int non-negative
+        :param AuthRelationId: 主体关系ID
+        :type AuthRelationId: int
         """
         self.Name = None
         self.PolicyType = None
@@ -96,6 +160,9 @@ class CreateOrganizationMemberRequest(AbstractModel):
         self.AccountName = None
         self.Remark = None
         self.RecordId = None
+        self.PayUin = None
+        self.IdentityRoleID = None
+        self.AuthRelationId = None
 
 
     def _deserialize(self, params):
@@ -106,6 +173,9 @@ class CreateOrganizationMemberRequest(AbstractModel):
         self.AccountName = params.get("AccountName")
         self.Remark = params.get("Remark")
         self.RecordId = params.get("RecordId")
+        self.PayUin = params.get("PayUin")
+        self.IdentityRoleID = params.get("IdentityRoleID")
+        self.AuthRelationId = params.get("AuthRelationId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -122,13 +192,18 @@ class CreateOrganizationMemberResponse(AbstractModel):
 
     def __init__(self):
         r"""
+        :param Uin: 成员Uin
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Uin: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
+        self.Uin = None
         self.RequestId = None
 
 
     def _deserialize(self, params):
+        self.Uin = params.get("Uin")
         self.RequestId = params.get("RequestId")
 
 
@@ -147,11 +222,17 @@ class DescribeOrganizationMembersRequest(AbstractModel):
         :type Lang: str
         :param SearchKey: 成员名或者成员ID搜索
         :type SearchKey: str
+        :param AuthName: 主体名称
+        :type AuthName: str
+        :param Product: 集团服务（服务管理员查询时，必须指定）
+        :type Product: str
         """
         self.Offset = None
         self.Limit = None
         self.Lang = None
         self.SearchKey = None
+        self.AuthName = None
+        self.Product = None
 
 
     def _deserialize(self, params):
@@ -159,6 +240,8 @@ class DescribeOrganizationMembersRequest(AbstractModel):
         self.Limit = params.get("Limit")
         self.Lang = params.get("Lang")
         self.SearchKey = params.get("SearchKey")
+        self.AuthName = params.get("AuthName")
+        self.Product = params.get("Product")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -207,12 +290,16 @@ class DescribeOrganizationRequest(AbstractModel):
         r"""
         :param Lang: 国际站：en，国内站：zh
         :type Lang: str
+        :param Product: 产品简称（查询是否集团服务委派管理员必填）
+        :type Product: str
         """
         self.Lang = None
+        self.Product = None
 
 
     def _deserialize(self, params):
         self.Lang = params.get("Lang")
+        self.Product = params.get("Product")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -265,6 +352,18 @@ class DescribeOrganizationResponse(AbstractModel):
         :param IsAllowQuit: 是否允许退出。允许：Allow，不允许：Denied。
 注意：此字段可能返回 null，表示取不到有效值。
         :type IsAllowQuit: str
+        :param PayUin: 代付者Uin
+注意：此字段可能返回 null，表示取不到有效值。
+        :type PayUin: str
+        :param PayName: 代付者名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :type PayName: str
+        :param IsAssignManager: 是否集团服务委派管理员 true-是、false-否
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IsAssignManager: bool
+        :param IsAuthManager: 是否主体管理员 true-是、false-否
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IsAuthManager: bool
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -280,6 +379,10 @@ class DescribeOrganizationResponse(AbstractModel):
         self.CreateTime = None
         self.JoinTime = None
         self.IsAllowQuit = None
+        self.PayUin = None
+        self.PayName = None
+        self.IsAssignManager = None
+        self.IsAuthManager = None
         self.RequestId = None
 
 
@@ -301,9 +404,43 @@ class DescribeOrganizationResponse(AbstractModel):
         self.CreateTime = params.get("CreateTime")
         self.JoinTime = params.get("JoinTime")
         self.IsAllowQuit = params.get("IsAllowQuit")
+        self.PayUin = params.get("PayUin")
+        self.PayName = params.get("PayName")
+        self.IsAssignManager = params.get("IsAssignManager")
+        self.IsAuthManager = params.get("IsAuthManager")
         self.RequestId = params.get("RequestId")
 
 
+class MemberIdentity(AbstractModel):
+    """成员管理身份
+
+    """
+
+    def __init__(self):
+        r"""
+        :param IdentityId: 身份ID。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IdentityId: int
+        :param IdentityAliasName: 身份名称。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IdentityAliasName: str
+        """
+        self.IdentityId = None
+        self.IdentityAliasName = None
+
+
+    def _deserialize(self, params):
+        self.IdentityId = params.get("IdentityId")
+        self.IdentityAliasName = params.get("IdentityAliasName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class OrgMember(AbstractModel):
     """企业组织成员
 
@@ -347,6 +484,21 @@ class OrgMember(AbstractModel):
         :param IsAllowQuit: 是否允许成员退出。允许：Allow，不允许：Denied。
 注意：此字段可能返回 null，表示取不到有效值。
         :type IsAllowQuit: str
+        :param PayUin: 代付者Uin
+注意：此字段可能返回 null，表示取不到有效值。
+        :type PayUin: str
+        :param PayName: 代付者名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :type PayName: str
+        :param OrgIdentity: 管理身份
+注意：此字段可能返回 null，表示取不到有效值。
+        :type OrgIdentity: list of MemberIdentity
+        :param BindStatus: 安全信息绑定状态  未绑定：Unbound，待激活：Valid，绑定成功：Success，绑定失败：Failed
+注意：此字段可能返回 null，表示取不到有效值。
+        :type BindStatus: str
+        :param PermissionStatus: 成员权限状态 已确认：Confirmed ，待确认：UnConfirmed
+注意：此字段可能返回 null，表示取不到有效值。
+        :type PermissionStatus: str
         """
         self.MemberUin = None
         self.Name = None
@@ -360,6 +512,11 @@ class OrgMember(AbstractModel):
         self.CreateTime = None
         self.UpdateTime = None
         self.IsAllowQuit = None
+        self.PayUin = None
+        self.PayName = None
+        self.OrgIdentity = None
+        self.BindStatus = None
+        self.PermissionStatus = None
 
 
     def _deserialize(self, params):
@@ -380,6 +537,16 @@ class OrgMember(AbstractModel):
         self.CreateTime = params.get("CreateTime")
         self.UpdateTime = params.get("UpdateTime")
         self.IsAllowQuit = params.get("IsAllowQuit")
+        self.PayUin = params.get("PayUin")
+        self.PayName = params.get("PayName")
+        if params.get("OrgIdentity") is not None:
+            self.OrgIdentity = []
+            for item in params.get("OrgIdentity"):
+                obj = MemberIdentity()
+                obj._deserialize(item)
+                self.OrgIdentity.append(obj)
+        self.BindStatus = params.get("BindStatus")
+        self.PermissionStatus = params.get("PermissionStatus")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
